userinput

package module
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 20, 2023 License: MIT Imports: 5 Imported by: 1

README

User Input

📖 Description

A package to get user input, navigate using the arrow key, and able to edit input.


💻 Import the package

import "github.com/allancapistrano/user-input"

📝 Example

package main

import (
	"fmt"

	"github.com/allancapistrano/user-input"
)

func main() {
	input := userinput.GetUserInput("Enter the text to be displayed: ")

	fmt.Println("\nInput: " + input)
}

👨💻 Author

Allan Capistrano
Allan Capistrano

My socials:

Github icon   Linkedin icon   Email icon


🙏 Support

Please ⭐ this repository if this project is useful or has helped you.


⚖ Licença

MIT LICENSE

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetUserInput

func GetUserInput(displayMessage string) string

Types

This section is empty.

Directories

Path Synopsis

Jump to