User Input
📖 Description
A package to get user input, navigate using the arrow key, and able to edit input.
💻 Import the package
import "github.com/allancapistrano/user-input"
📝 Example
package main
import (
"fmt"
"github.com/allancapistrano/user-input"
)
func main() {
input := userinput.GetUserInput("Enter the text to be displayed: ")
fmt.Println("\nInput: " + input)
}
👨💻 Author
My socials:
🙏 Support
Please ⭐ this repository if this project is useful or has helped you.

⚖ Licença
MIT LICENSE